Working with Images
-------------------

.. note::

   This document provides a collection of worksheets which
   describes the creation and setup of appliances to work
   within a number of different target environments.
   
.. toctree::
   :maxdepth: 1

   working_with_images/iso_to_usb_stick_deployment
   working_with_images/iso_to_usb_stick_file_based_deployment
   working_with_images/iso_to_usb_stick_grub2_boot_from_iso

   working_with_images/disk_setup_for_ec2
   working_with_images/disk_setup_for_azure
   working_with_images/disk_setup_for_google
   working_with_images/disk_setup_for_vagrant
   working_with_images/disk_setup_for_luks
   working_with_images/disk_ramdisk_deployment

   working_with_images/custom_partitions
   working_with_images/custom_volumes

   working_with_images/setup_network_bootserver
   working_with_images/legacy_netboot_root_filesystem
   working_with_images/network_overlay_boot
   working_with_images/network_live_iso_boot

   working_with_images/setup_yast_on_first_boot
   working_with_images/custom_fstab_extension
   working_with_images/build_with_profiles
   working_with_images/build_in_buildservice
   working_with_images/use_suse_media
